track_duration

Function track_duration 

pub fn track_duration<'a, C: CategoryString, S: AsTraceStrRef>(
    category: C,
    name: S,
    track: &'a Track,
    args: &'a [Arg<'_>],
) -> TrackDurationScope<'a, C, S>
Writes a duration event to a custom track which ends when the returned guard is dropped.

0 to 15 arguments can be associated with the event, each of which is used to annotate the duration with additional information.