pub fn track_duration_begin<S1: AsTraceStrRef>(
context: &TraceCategoryContext,
name: S1,
track: &Track,
args: &[Arg<'_>],
)Expand description
Writes a duration begin event to a custom track.
pub fn track_duration_begin<S1: AsTraceStrRef>(
context: &TraceCategoryContext,
name: S1,
track: &Track,
args: &[Arg<'_>],
)Writes a duration begin event to a custom track.