pub fn track_duration_end<S1: AsTraceStrRef>(
context: &TraceCategoryContext,
name: S1,
track: &Track,
args: &[Arg<'_>],
)Expand description
Writes a duration end event to a custom track.
pub fn track_duration_end<S1: AsTraceStrRef>(
context: &TraceCategoryContext,
name: S1,
track: &Track,
args: &[Arg<'_>],
)Writes a duration end event to a custom track.