track_instant

Function track_instant 

pub fn track_instant<S1: AsTraceStrRef>(
    context: &TraceCategoryContext,
    name: S1,
    track: &Track,
    scope: Scope,
    args: &[Arg<'_>],
)
Writes an instant event to a custom track.

NOTE: Instant events emitted to a custom track should generally be emitted with Scope::Thread to guarantee that the Perfetto UI renders them directly on the custom track rather than process-wide.