macro_rules! track_duration_begin {
($category:expr, $track:expr, $name:expr $(, $key:expr => $val:expr)* $(,)?) => { ... };
}Expand description
Writes a duration begin event to a custom track.
macro_rules! track_duration_begin {
($category:expr, $track:expr, $name:expr $(, $key:expr => $val:expr)* $(,)?) => { ... };
}Writes a duration begin event to a custom track.