macro_rules! track_duration_end {
($category:expr, $track:expr, $name:expr $(, $key:expr => $val:expr)* $(,)?) => { ... };
}Expand description
Writes a duration end event to a custom track.
macro_rules! track_duration_end {
($category:expr, $track:expr, $name:expr $(, $key:expr => $val:expr)* $(,)?) => { ... };
}Writes a duration end event to a custom track.