TrackDurationScope

Struct TrackDurationScope 

pub struct TrackDurationScope<'a, C: CategoryString, S: AsTraceStrRef> { /* private fields */ }
Scoped duration guard for a custom track. The duration ends and the trace record is written when the guard is dropped.

Under the hood, when the guard is dropped, it writes a single, complete DurationComplete event to the track backing virtual thread, which contains both the start time (stored in the guard) and the end time (determined at drop). This is highly efficient as it only writes a single record to the trace buffer.

Implementations

Source

impl<'a, C: CategoryString, S: AsTraceStrRef> TrackDurationScope<'a, C, S>

pub fn begin( category: C, name: S, track: &'a Track, args: &'a [Arg<'_>], ) -> Self

Starts a new duration scope that starts now and will be end’ed when dropped.