pub struct TrackDurationScope<'a, C: CategoryString, S: AsTraceStrRef> { /* private fields */ }Expand description
Scoped duration guard for a custom track. The duration ends and the trace record is written when the guard is dropped.
Under the hood, when the guard is dropped, it writes a single, complete DurationComplete
event to the track backing virtual thread, which contains both the start time (stored in the
guard) and the end time (determined at drop). This is highly efficient as it only writes a
single record to the trace buffer.
Implementations
Sourceimpl<'a, C: CategoryString, S: AsTraceStrRef> TrackDurationScope<'a, C, S>
impl<'a, C: CategoryString, S: AsTraceStrRef> TrackDurationScope<'a, C, S>